==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-fancymenu/translations/fancymenu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Afficher/Cacher le menu principal</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation>Toutes les Applications</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation>Paramètres de Fancy Menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texte du bouton :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Taille de police personnalisée :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Sélection auto après :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Fichier du menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Fichier du menu :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Raccourci clavier</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Cliquer sur le bouton pour enregistrer le raccourci :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Remettre à zéro la recherche lors de l&apos;affichage du menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Disposition</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Position de la rangée de boutons</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Position des catégories</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Choisir un fichier d&apos;icône</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Images (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Choisir un fichier de menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Fichiers de menu (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="153"/>
        <source>Search...</source>
        <translation>Rechercher...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="160"/>
        <source>LXQt Configuration Center</source>
        <translation>Centre de configuration LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="166"/>
        <source>Leave</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="172"/>
        <source>About LXQt</source>
        <translation>À propos de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="185"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation>Ajoutez vos favoris avec un clic droit sur les éléments dans les catégories.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="345"/>
        <source>Add to desktop</source>
        <translation>Ajouter au bureau</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="353"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="354"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Un fichier du même nom existe déjà.
Voulez-vous l&apos;écraser ?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="360"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="361"/>
        <source>The file cannot be overwritten.</source>
        <translation>Le fichier ne peut pas être écrasé.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="368"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="381"/>
        <source>Remove from Favorites</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="388"/>
        <source>Add to Favorites</source>
        <translation>Ajouter aux favoris</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="572"/>
        <source>No Executable</source>
        <translation>Aucun exécutable</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="573"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>Impossible de trouver l&apos;exécutable &lt;b&gt;%1&lt;/b&gt;.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.0.1.orig.tar.xz: lxqt-panel-2.0.1/plugin-fancymenu/translations/fancymenu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Afficher/Cacher le menu principal</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation>Toutes les Applications</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation>Paramètres de Fancy Menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texte du bouton :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Taille de police personnalisée :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Sélection auto après&#xa0;:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Fichier du menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Fichier du menu :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Raccourci clavier</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Cliquer sur le bouton pour enregistrer le raccourci :</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Remettre à zéro la recherche lors de l&apos;affichage du menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Disposition</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Position de la rangée de boutons</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Position des catégories</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Choisir un fichier d&apos;icône</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Images (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Choisir un fichier de menu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Fichiers de menu (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Rechercher...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation>Centre de configuration LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation>À propos de LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="188"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation>Ajoutez vos favoris avec un clic droit sur les éléments dans les catégories.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="354"/>
        <source>Add to desktop</source>
        <translation>Ajouter au bureau</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="362"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="363"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Un fichier du même nom existe déjà.
Voulez-vous l&apos;écraser&#x202f;?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="369"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="370"/>
        <source>The file cannot be overwritten.</source>
        <translation>Le fichier ne peut pas être écrasé.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="377"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="390"/>
        <source>Remove from Favorites</source>
        <translation>Retirer des favoris</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="397"/>
        <source>Add to Favorites</source>
        <translation>Ajouter aux favoris</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="703"/>
        <source>No Executable</source>
        <translation>Aucun exécutable</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="704"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>Impossible de trouver l&apos;exécutable &lt;b&gt;%1&lt;/b&gt;.</translation>
    </message>
</context>
</TS>
